@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-
 def parse_output(output_array):
     squeue_info = {}
     default_values = {
@@ -13,8 +12,8 @@ def parse_output(output_array):
         'COMPLETED': 0,
         'CONFIGURING': 0,
         'FAILED': 0,
-        'TIME_OUT': 0,
-        'PRE_EMPTED': 0,
+        'TIMEOUT': 0,
+        'PREEMPTED': 0,
         'NODE_FAIL': 0,
     }
 
